==> hudder-8.0.8-sources.jar: io/github/ngspace/hudder/utils/CachedReader.java <==
package io.github.ngspace.hudder.utils;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Map.Entry;
import java.util.Scanner;
import net.minecraft.class_1011;
import net.minecraft.class_1043;
import net.minecraft.class_2960;
import net.minecraft.class_310;

public class CachedReader {
	
	protected static class_310 mc = class_310.method_1551();
	
	
	HashMap<String, String> savedFiles = new HashMap<String, String>();
	HashMap<class_2960, class_1043> savedImages = new HashMap<class_2960, class_1043>();
	
	
	
	public String readFile(String file) {return savedFiles.get(file);}
	
	
	
	public boolean readFileAndSaveToCache(File f) throws IOException {
		if (!f.exists()) {
			f.getParentFile().mkdirs();
			if (!f.createNewFile()) return false;
		}
		savedFiles.put(f.getAbsolutePath(),readFileLineByLine(f));
		return true;
	}
	
	public String readFileLineByLine(File f) throws IOException {
		Scanner reader = new Scanner(f);
		String res = "";
		while (reader.hasNextLine()) {
			res += reader.nextLine();
			res += '\n';
		}
		reader.close();
		if (res.isEmpty()) return res;
		return res.substring(0, res.length()-1);
	}
	
	
	
	public boolean registerAndCacheImage(InputStream inputStream, class_2960 id) throws IOException {
		if (savedImages.containsKey(id)) {
			mc.method_1531().method_4615(id);
			savedImages.get(id).close();
			savedImages.remove(id);
		}
		class_1011 img = class_1011.method_4309(inputStream);
		class_1043 tex = new class_1043(img);
		mc.method_1531().method_4616(id, tex);
		
		savedImages.put(id,tex);
		return true;
	}
	
	
	
	/**
	 * Clears Cache
	 */
	public void clearCache() {
		for (Entry<class_2960, class_1043> v : savedImages.entrySet()) {
			mc.method_1531().method_4615(v.getKey());
			v.getValue().close();
		}
		savedImages.clear();
		savedFiles.clear();
	}
}

==> hudder-8.4.1-sources.jar: io/github/ngspace/hudder/utils/CachedReader.java <==
package io.github.ngspace.hudder.utils;

import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.HashMap;
import java.util.Map.Entry;
import java.util.Scanner;
import net.minecraft.class_1011;
import net.minecraft.class_1043;
import net.minecraft.class_2960;
import net.minecraft.class_310;

public class CachedReader {
	
	protected static class_310 mc = class_310.method_1551();
	
	
	HashMap<String, String> savedFiles = new HashMap<String, String>();
	HashMap<class_2960, class_1043> savedImages = new HashMap<class_2960, class_1043>();
	
	
	
	public String readFile(String file) {return savedFiles.get(file);}
	
	
	
	public boolean readFileAndSaveToCache(File f) throws IOException {
		if (!f.exists()) {
			f.getParentFile().mkdirs();
			if (!f.createNewFile()) return false;
		}
		savedFiles.put(f.getAbsolutePath(),readFileLineByLine(f));
		return true;
	}
	
	public String readFileLineByLine(File f) throws IOException {
		Scanner reader = new Scanner(f);
		String res = "";
		while (reader.hasNextLine()) {
			res += reader.nextLine();
			res += '\n';
		}
		reader.close();
		if (res.isEmpty()) return res;
		return res.substring(0, res.length()-1);
	}
	
	
	
	public boolean registerAndCacheImage(InputStream inputStream, class_2960 id) throws IOException {
		if (savedImages.containsKey(id)) {
			mc.method_1531().method_4615(id);
			savedImages.get(id).close();
			savedImages.remove(id);
		}
		class_1011 img = class_1011.method_4309(inputStream);
		class_1043 tex = new class_1043(id::method_12832,img);
		mc.method_1531().method_4616(id, tex);
		
		savedImages.put(id,tex);
		return true;
	}
	
	
	
	/**
	 * Clears Cache
	 */
	public void clearCache() {
		for (Entry<class_2960, class_1043> v : savedImages.entrySet()) {
			mc.method_1531().method_4615(v.getKey());
			v.getValue().close();
		}
		savedImages.clear();
		savedFiles.clear();
	}
}
